OEXEngine class

Constructors

OEXEngine(String packageName, String name, int versionCode, String fileName, String enginePath)

Properties

enginePath → String
final
errStream → Stream<String>
no setter
fileName → String
final
hashCode → int
The hash code for this object.
no setterinherited
isRunning → bool
no setter
name → String
final
outStream → Stream<String>
no setter
packageName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(String message) → void
start() → Future<Stream<String>>
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited